@@ -126,7 +126,7 @@ describe 'oslo::cache' do
         }
       end
 
-      it 'configures oslo_policy section with overriden list values as strings' do
+      it 'configures oslo_policy section with overridden list values as strings' do
         is_expected.to contain_keystone_config('cache/backend_argument').with_value('foo:bar')
         is_expected.to contain_keystone_config('cache/memcache_servers').with_value('host1:11211,host2:11211')
         is_expected.to contain_keystone_config('cache/proxies').with_value('proxy1,proxy2')
@@ -142,11 +142,24 @@ describe 'oslo::cache' do
         facts.merge!(OSDefaults.get_facts())
       end
       let(:platform_params) do
-        platform_params = { :pylibmc_package_name => 'python-pylibmc' }
+        case facts[:osfamily]
+        when 'Debian'
+          if facts[:os_package_type] == 'debian'
+            platform_params = { :pylibmc_package_name => 'python3-pylibmc' }
+          else
+            platform_params = { :pylibmc_package_name => 'python-pylibmc' }
+          end
+        when 'RedHat'
+          platform_params = { :pylibmc_package_name => 'python-pylibmc' }
+        end
 
         case facts[:osfamily]
         when 'Debian'
-          platform_params[:python_memcache_package_name] = 'python-memcache'
+          if facts[:os_package_type] == 'debian'
+            platform_params[:python_memcache_package_name] = 'python3-memcache'
+          else
+            platform_params[:python_memcache_package_name] = 'python-memcache'
+          end
         when 'RedHat'
           platform_params[:python_memcache_package_name] = 'python-memcached'
         end
